#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gtk
version:                3.0.43
visibility:             public
id:                     gi-gtk-3.0.43-6iem7vPI22GBr9g4fdf2Gm
key:                    gi-gtk-3.0.43-6iem7vPI22GBr9g4fdf2Gm
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Gtk bindings
description:            Bindings for Gtk, autogenerated by haskell-gi.
category:               Bindings
abi:                    2049cc0b07b2fd2d863fda559a5b1a88
exposed:                True
exposed-modules:
    GI.Gtk GI.Gtk.Callbacks GI.Gtk.Config GI.Gtk.Constants GI.Gtk.Enums
    GI.Gtk.Flags GI.Gtk.Functions GI.Gtk.Interfaces
    GI.Gtk.Interfaces.Actionable GI.Gtk.Interfaces.Activatable
    GI.Gtk.Interfaces.AppChooser GI.Gtk.Interfaces.Buildable
    GI.Gtk.Interfaces.CellAccessibleParent
    GI.Gtk.Interfaces.CellEditable GI.Gtk.Interfaces.CellLayout
    GI.Gtk.Interfaces.ColorChooser GI.Gtk.Interfaces.Editable
    GI.Gtk.Interfaces.FileChooser GI.Gtk.Interfaces.FontChooser
    GI.Gtk.Interfaces.Orientable
    GI.Gtk.Interfaces.PrintOperationPreview
    GI.Gtk.Interfaces.RecentChooser GI.Gtk.Interfaces.Scrollable
    GI.Gtk.Interfaces.StyleProvider GI.Gtk.Interfaces.ToolShell
    GI.Gtk.Interfaces.TreeDragDest GI.Gtk.Interfaces.TreeDragSource
    GI.Gtk.Interfaces.TreeModel GI.Gtk.Interfaces.TreeSortable
    GI.Gtk.Objects GI.Gtk.Objects.AboutDialog GI.Gtk.Objects.AccelGroup
    GI.Gtk.Objects.AccelLabel GI.Gtk.Objects.AccelMap
    GI.Gtk.Objects.Accessible GI.Gtk.Objects.Action
    GI.Gtk.Objects.ActionBar GI.Gtk.Objects.ActionGroup
    GI.Gtk.Objects.Adjustment GI.Gtk.Objects.Alignment
    GI.Gtk.Objects.AppChooserButton GI.Gtk.Objects.AppChooserDialog
    GI.Gtk.Objects.AppChooserWidget GI.Gtk.Objects.Application
    GI.Gtk.Objects.ApplicationWindow GI.Gtk.Objects.Arrow
    GI.Gtk.Objects.ArrowAccessible GI.Gtk.Objects.AspectFrame
    GI.Gtk.Objects.Assistant GI.Gtk.Objects.Bin
    GI.Gtk.Objects.BooleanCellAccessible GI.Gtk.Objects.Box
    GI.Gtk.Objects.Builder GI.Gtk.Objects.Button
    GI.Gtk.Objects.ButtonAccessible GI.Gtk.Objects.ButtonBox
    GI.Gtk.Objects.Calendar GI.Gtk.Objects.CellAccessible
    GI.Gtk.Objects.CellArea GI.Gtk.Objects.CellAreaBox
    GI.Gtk.Objects.CellAreaContext GI.Gtk.Objects.CellRenderer
    GI.Gtk.Objects.CellRendererAccel GI.Gtk.Objects.CellRendererCombo
    GI.Gtk.Objects.CellRendererPixbuf
    GI.Gtk.Objects.CellRendererProgress GI.Gtk.Objects.CellRendererSpin
    GI.Gtk.Objects.CellRendererSpinner GI.Gtk.Objects.CellRendererText
    GI.Gtk.Objects.CellRendererToggle GI.Gtk.Objects.CellView
    GI.Gtk.Objects.CheckButton GI.Gtk.Objects.CheckMenuItem
    GI.Gtk.Objects.CheckMenuItemAccessible GI.Gtk.Objects.Clipboard
    GI.Gtk.Objects.ColorButton GI.Gtk.Objects.ColorChooserDialog
    GI.Gtk.Objects.ColorChooserWidget GI.Gtk.Objects.ColorSelection
    GI.Gtk.Objects.ColorSelectionDialog GI.Gtk.Objects.ComboBox
    GI.Gtk.Objects.ComboBoxAccessible GI.Gtk.Objects.ComboBoxText
    GI.Gtk.Objects.Container GI.Gtk.Objects.ContainerAccessible
    GI.Gtk.Objects.ContainerCellAccessible GI.Gtk.Objects.CssProvider
    GI.Gtk.Objects.Dialog GI.Gtk.Objects.DrawingArea
    GI.Gtk.Objects.Entry GI.Gtk.Objects.EntryAccessible
    GI.Gtk.Objects.EntryBuffer GI.Gtk.Objects.EntryCompletion
    GI.Gtk.Objects.EntryIconAccessible GI.Gtk.Objects.EventBox
    GI.Gtk.Objects.EventController GI.Gtk.Objects.EventControllerKey
    GI.Gtk.Objects.EventControllerMotion
    GI.Gtk.Objects.EventControllerScroll GI.Gtk.Objects.Expander
    GI.Gtk.Objects.ExpanderAccessible GI.Gtk.Objects.FileChooserButton
    GI.Gtk.Objects.FileChooserDialog GI.Gtk.Objects.FileChooserNative
    GI.Gtk.Objects.FileChooserWidget
    GI.Gtk.Objects.FileChooserWidgetAccessible
    GI.Gtk.Objects.FileFilter GI.Gtk.Objects.Fixed
    GI.Gtk.Objects.FlowBox GI.Gtk.Objects.FlowBoxAccessible
    GI.Gtk.Objects.FlowBoxChild GI.Gtk.Objects.FlowBoxChildAccessible
    GI.Gtk.Objects.FontButton GI.Gtk.Objects.FontChooserDialog
    GI.Gtk.Objects.FontChooserWidget GI.Gtk.Objects.FontSelection
    GI.Gtk.Objects.FontSelectionDialog GI.Gtk.Objects.Frame
    GI.Gtk.Objects.FrameAccessible GI.Gtk.Objects.GLArea
    GI.Gtk.Objects.Gesture GI.Gtk.Objects.GestureDrag
    GI.Gtk.Objects.GestureLongPress GI.Gtk.Objects.GestureMultiPress
    GI.Gtk.Objects.GesturePan GI.Gtk.Objects.GestureRotate
    GI.Gtk.Objects.GestureSingle GI.Gtk.Objects.GestureStylus
    GI.Gtk.Objects.GestureSwipe GI.Gtk.Objects.GestureZoom
    GI.Gtk.Objects.Grid GI.Gtk.Objects.HBox GI.Gtk.Objects.HButtonBox
    GI.Gtk.Objects.HPaned GI.Gtk.Objects.HSV GI.Gtk.Objects.HScale
    GI.Gtk.Objects.HScrollbar GI.Gtk.Objects.HSeparator
    GI.Gtk.Objects.HandleBox GI.Gtk.Objects.HeaderBar
    GI.Gtk.Objects.HeaderBarAccessible GI.Gtk.Objects.IMContext
    GI.Gtk.Objects.IMContextSimple GI.Gtk.Objects.IMMulticontext
    GI.Gtk.Objects.IconFactory GI.Gtk.Objects.IconInfo
    GI.Gtk.Objects.IconTheme GI.Gtk.Objects.IconView
    GI.Gtk.Objects.IconViewAccessible GI.Gtk.Objects.Image
    GI.Gtk.Objects.ImageAccessible GI.Gtk.Objects.ImageCellAccessible
    GI.Gtk.Objects.ImageMenuItem GI.Gtk.Objects.InfoBar
    GI.Gtk.Objects.Invisible GI.Gtk.Objects.Label
    GI.Gtk.Objects.LabelAccessible GI.Gtk.Objects.Layout
    GI.Gtk.Objects.LevelBar GI.Gtk.Objects.LevelBarAccessible
    GI.Gtk.Objects.LinkButton GI.Gtk.Objects.LinkButtonAccessible
    GI.Gtk.Objects.ListBox GI.Gtk.Objects.ListBoxAccessible
    GI.Gtk.Objects.ListBoxRow GI.Gtk.Objects.ListBoxRowAccessible
    GI.Gtk.Objects.ListStore GI.Gtk.Objects.LockButton
    GI.Gtk.Objects.LockButtonAccessible GI.Gtk.Objects.Menu
    GI.Gtk.Objects.MenuAccessible GI.Gtk.Objects.MenuBar
    GI.Gtk.Objects.MenuButton GI.Gtk.Objects.MenuButtonAccessible
    GI.Gtk.Objects.MenuItem GI.Gtk.Objects.MenuItemAccessible
    GI.Gtk.Objects.MenuShell GI.Gtk.Objects.MenuShellAccessible
    GI.Gtk.Objects.MenuToolButton GI.Gtk.Objects.MessageDialog
    GI.Gtk.Objects.Misc GI.Gtk.Objects.ModelButton
    GI.Gtk.Objects.MountOperation GI.Gtk.Objects.NativeDialog
    GI.Gtk.Objects.Notebook GI.Gtk.Objects.NotebookAccessible
    GI.Gtk.Objects.NotebookPageAccessible GI.Gtk.Objects.NumerableIcon
    GI.Gtk.Objects.OffscreenWindow GI.Gtk.Objects.Overlay
    GI.Gtk.Objects.PadController GI.Gtk.Objects.PageSetup
    GI.Gtk.Objects.Paned GI.Gtk.Objects.PanedAccessible
    GI.Gtk.Objects.PlacesSidebar GI.Gtk.Objects.Plug
    GI.Gtk.Objects.PlugAccessible GI.Gtk.Objects.Popover
    GI.Gtk.Objects.PopoverAccessible GI.Gtk.Objects.PopoverMenu
    GI.Gtk.Objects.PrintContext GI.Gtk.Objects.PrintOperation
    GI.Gtk.Objects.PrintSettings GI.Gtk.Objects.ProgressBar
    GI.Gtk.Objects.ProgressBarAccessible GI.Gtk.Objects.RadioAction
    GI.Gtk.Objects.RadioButton GI.Gtk.Objects.RadioButtonAccessible
    GI.Gtk.Objects.RadioMenuItem GI.Gtk.Objects.RadioMenuItemAccessible
    GI.Gtk.Objects.RadioToolButton GI.Gtk.Objects.Range
    GI.Gtk.Objects.RangeAccessible GI.Gtk.Objects.RcStyle
    GI.Gtk.Objects.RecentAction GI.Gtk.Objects.RecentChooserDialog
    GI.Gtk.Objects.RecentChooserMenu GI.Gtk.Objects.RecentChooserWidget
    GI.Gtk.Objects.RecentFilter GI.Gtk.Objects.RecentManager
    GI.Gtk.Objects.RendererCellAccessible GI.Gtk.Objects.Revealer
    GI.Gtk.Objects.Scale GI.Gtk.Objects.ScaleAccessible
    GI.Gtk.Objects.ScaleButton GI.Gtk.Objects.ScaleButtonAccessible
    GI.Gtk.Objects.Scrollbar GI.Gtk.Objects.ScrolledWindow
    GI.Gtk.Objects.ScrolledWindowAccessible GI.Gtk.Objects.SearchBar
    GI.Gtk.Objects.SearchEntry GI.Gtk.Objects.Separator
    GI.Gtk.Objects.SeparatorMenuItem GI.Gtk.Objects.SeparatorToolItem
    GI.Gtk.Objects.Settings GI.Gtk.Objects.ShortcutLabel
    GI.Gtk.Objects.ShortcutsGroup GI.Gtk.Objects.ShortcutsSection
    GI.Gtk.Objects.ShortcutsShortcut GI.Gtk.Objects.ShortcutsWindow
    GI.Gtk.Objects.SizeGroup GI.Gtk.Objects.Socket
    GI.Gtk.Objects.SocketAccessible GI.Gtk.Objects.SpinButton
    GI.Gtk.Objects.SpinButtonAccessible GI.Gtk.Objects.Spinner
    GI.Gtk.Objects.SpinnerAccessible GI.Gtk.Objects.Stack
    GI.Gtk.Objects.StackAccessible GI.Gtk.Objects.StackSidebar
    GI.Gtk.Objects.StackSwitcher GI.Gtk.Objects.StatusIcon
    GI.Gtk.Objects.Statusbar GI.Gtk.Objects.StatusbarAccessible
    GI.Gtk.Objects.Style GI.Gtk.Objects.StyleContext
    GI.Gtk.Objects.StyleProperties GI.Gtk.Objects.Switch
    GI.Gtk.Objects.SwitchAccessible GI.Gtk.Objects.Table
    GI.Gtk.Objects.TearoffMenuItem GI.Gtk.Objects.TextBuffer
    GI.Gtk.Objects.TextCellAccessible GI.Gtk.Objects.TextChildAnchor
    GI.Gtk.Objects.TextMark GI.Gtk.Objects.TextTag
    GI.Gtk.Objects.TextTagTable GI.Gtk.Objects.TextView
    GI.Gtk.Objects.TextViewAccessible GI.Gtk.Objects.ThemingEngine
    GI.Gtk.Objects.ToggleAction GI.Gtk.Objects.ToggleButton
    GI.Gtk.Objects.ToggleButtonAccessible
    GI.Gtk.Objects.ToggleToolButton GI.Gtk.Objects.ToolButton
    GI.Gtk.Objects.ToolItem GI.Gtk.Objects.ToolItemGroup
    GI.Gtk.Objects.ToolPalette GI.Gtk.Objects.Toolbar
    GI.Gtk.Objects.Tooltip GI.Gtk.Objects.ToplevelAccessible
    GI.Gtk.Objects.TreeModelFilter GI.Gtk.Objects.TreeModelSort
    GI.Gtk.Objects.TreeSelection GI.Gtk.Objects.TreeStore
    GI.Gtk.Objects.TreeView GI.Gtk.Objects.TreeViewAccessible
    GI.Gtk.Objects.TreeViewColumn GI.Gtk.Objects.UIManager
    GI.Gtk.Objects.VBox GI.Gtk.Objects.VButtonBox GI.Gtk.Objects.VPaned
    GI.Gtk.Objects.VScale GI.Gtk.Objects.VScrollbar
    GI.Gtk.Objects.VSeparator GI.Gtk.Objects.Viewport
    GI.Gtk.Objects.VolumeButton GI.Gtk.Objects.Widget
    GI.Gtk.Objects.WidgetAccessible GI.Gtk.Objects.Window
    GI.Gtk.Objects.WindowAccessible GI.Gtk.Objects.WindowGroup
    GI.Gtk.Structs GI.Gtk.Structs.AccelGroupEntry
    GI.Gtk.Structs.AccelKey GI.Gtk.Structs.ActionEntry
    GI.Gtk.Structs.ActionableInterface GI.Gtk.Structs.BindingArg
    GI.Gtk.Structs.BindingEntry GI.Gtk.Structs.BindingSet
    GI.Gtk.Structs.BindingSignal GI.Gtk.Structs.Border
    GI.Gtk.Structs.ContainerClass GI.Gtk.Structs.CssSection
    GI.Gtk.Structs.FileFilterInfo GI.Gtk.Structs.FixedChild
    GI.Gtk.Structs.Gradient GI.Gtk.Structs.IMContextInfo
    GI.Gtk.Structs.IconSet GI.Gtk.Structs.IconSource
    GI.Gtk.Structs.LabelSelectionInfo
    GI.Gtk.Structs.MountOperationHandlerIface_
    GI.Gtk.Structs.MountOperationHandlerProxyClass_
    GI.Gtk.Structs.MountOperationHandlerProxy_
    GI.Gtk.Structs.MountOperationHandlerSkeletonClass_
    GI.Gtk.Structs.MountOperationHandlerSkeleton_
    GI.Gtk.Structs.MountOperationHandler_ GI.Gtk.Structs.PadActionEntry
    GI.Gtk.Structs.PageRange GI.Gtk.Structs.PaperSize
    GI.Gtk.Structs.RadioActionEntry GI.Gtk.Structs.RcContext
    GI.Gtk.Structs.RcProperty GI.Gtk.Structs.RecentData
    GI.Gtk.Structs.RecentFilterInfo GI.Gtk.Structs.RecentInfo
    GI.Gtk.Structs.RequestedSize GI.Gtk.Structs.Requisition
    GI.Gtk.Structs.SelectionData GI.Gtk.Structs.SettingsValue
    GI.Gtk.Structs.StockItem GI.Gtk.Structs.SymbolicColor
    GI.Gtk.Structs.TableChild GI.Gtk.Structs.TableRowCol
    GI.Gtk.Structs.TargetEntry GI.Gtk.Structs.TargetList
    GI.Gtk.Structs.TargetPair GI.Gtk.Structs.TextAppearance
    GI.Gtk.Structs.TextAttributes GI.Gtk.Structs.TextBTree
    GI.Gtk.Structs.TextIter GI.Gtk.Structs.ThemeEngine
    GI.Gtk.Structs.ToggleActionEntry GI.Gtk.Structs.TreeIter
    GI.Gtk.Structs.TreePath GI.Gtk.Structs.TreeRowReference
    GI.Gtk.Structs.WidgetClass GI.Gtk.Structs.WidgetPath
    GI.Gtk.Structs.WindowGeometryInfo

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gtk-3.0.43
library-dirs:           /usr/lib/ghc-9.6.6/site-local/gi-gtk-3.0.43 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/gi-gtk-3.0.43 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gtk3
hs-libraries:           HSgi-gtk-3.0.43-6iem7vPI22GBr9g4fdf2Gm
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 pthread atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl wayland-client
    m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie
    Xft cairo m dl fontconfig m expat m Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m harfbuzz-gobject
    harfbuzz m freetype dl bz2 png16 m m brotlidec brotlicommon
    graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 atomic m
    pcre2-8 pthread z mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-atk-2.0.28-Dk0ZIq8ygMn1uhftNImMfL
    gi-cairo-1.0.30-IBUoRBcBEARCuqZOPmUGw6
    gi-gdk-3.0.29-BY1DbO8s118WPbhQlYTp5
    gi-gdkpixbuf-2.0.32-7JuiBJoSnV61dj9SGLFftB
    gi-gio-2.0.38-38HHtPKeyR1AvEEJ0SErPX
    gi-glib-2.0.30-GLGYQ86E1CvI3tgg5m5jqn
    gi-gobject-2.0.31-J60Xf8c78Mf8aNOCTQvYD1
    gi-pango-1.0.30-FE1AwPee4qgIYt4sHUztpF
    haskell-gi-0.26.17-Fka2pidV6RX8yGrRXUUPtn
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-gtk3/html/gi-gtk.haddock
haddock-html:           /usr/share/doc/haskell-gi-gtk3/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

